@@ -75,6 +75,8 @@ def get_config(path):
     config_file.close()
     return yaml.load(content)
 
+def main():
+    run(get_args())
 
 if __name__ == '__main__':
-    run(get_args())
+    main()
